==> ejc-jltest-api-3.0.0-20240312.013724-62-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangereDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定明细E
 * 
 * @author generator
 * 
 */
public class DangereDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long dangerId; // 主表主键ID
    private Long detailCode; // 隐患编号
    private String detailType; // 隐患类别
    private String detailManagementLink; // 管理环节
    private String detailContent; // 隐患内容
    private String detailSelfCheck; // 自查情况
    private String detailResult; // 判定结果
    private String detailDescription; // 备注
    

    public Long getDangerId() {
        return dangerId;
    }

    public void setDangerId(Long dangerId) {
        this.dangerId = dangerId;
    }
    public Long getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(Long detailCode) {
        this.detailCode = detailCode;
    }
    public String getDetailType() {
        return detailType;
    }

    public void setDetailType(String detailType) {
        this.detailType = detailType;
    }
    public String getDetailManagementLink() {
        return detailManagementLink;
    }

    public void setDetailManagementLink(String detailManagementLink) {
        this.detailManagementLink = detailManagementLink;
    }
    public String getDetailContent() {
        return detailContent;
    }

    public void setDetailContent(String detailContent) {
        this.detailContent = detailContent;
    }
    public String getDetailSelfCheck() {
        return detailSelfCheck;
    }

    public void setDetailSelfCheck(String detailSelfCheck) {
        this.detailSelfCheck = detailSelfCheck;
    }
    public String getDetailResult() {
        return detailResult;
    }

    public void setDetailResult(String detailResult) {
        this.detailResult = detailResult;
    }
    public String getDetailDescription() {
        return detailDescription;
    }

    public void setDetailDescription(String detailDescription) {
        this.detailDescription = detailDescription;
    }
    
}

==> ejc-jltest-api-3.0.0-20240323.074114-106-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangereDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定明细E
 * 
 * @author generator
 * 
 */
public class DangereDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long dangerId; // 主表主键ID
    private Long detailCode; // 隐患编号
    private Long detailType; // 隐患类别
    private String detailManagementLink; // 管理环节
    private String detailContent; // 隐患内容
    private String detailSelfCheck; // 自查情况
    private String detailResult; // 判定结果
    private String detailDescription; // 备注
    

    public Long getDangerId() {
        return dangerId;
    }

    public void setDangerId(Long dangerId) {
        this.dangerId = dangerId;
    }
    public Long getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(Long detailCode) {
        this.detailCode = detailCode;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getDetailType() {
        return detailType;
    }

    @ReferDeserialTransfer
    public void setDetailType(Long detailType) {
        this.detailType = detailType;
    }

    public String getDetailManagementLink() {
        return detailManagementLink;
    }

    public void setDetailManagementLink(String detailManagementLink) {
        this.detailManagementLink = detailManagementLink;
    }
    public String getDetailContent() {
        return detailContent;
    }

    public void setDetailContent(String detailContent) {
        this.detailContent = detailContent;
    }
    public String getDetailSelfCheck() {
        return detailSelfCheck;
    }

    public void setDetailSelfCheck(String detailSelfCheck) {
        this.detailSelfCheck = detailSelfCheck;
    }
    public String getDetailResult() {
        return detailResult;
    }

    public void setDetailResult(String detailResult) {
        this.detailResult = detailResult;
    }
    public String getDetailDescription() {
        return detailDescription;
    }

    public void setDetailDescription(String detailDescription) {
        this.detailDescription = detailDescription;
    }
    
}
